import logging
from typing import Optional, Tuple, Type

from pydantic_settings import BaseSettings, PydanticBaseSettingsSource

logger = logging.getLogger(__name__)


class ConfigVars:
    env_file = ".env"
    env_file_encoding = "utf-8"

    @classmethod
    def customise_sources(
        cls,
        settings_cls: Type[BaseSettings],
        init_settings: PydanticBaseSettingsSource,
        env_settings: PydanticBaseSettingsSource,
        dotenv_settings: PydanticBaseSettingsSource,
    ) -> Tuple[PydanticBaseSettingsSource, ...]:
        return (
            init_settings,
            env_settings,
            dotenv_settings,
        )


class Settings(BaseSettings):
    debug: bool = False
    host: str = "127.0.0.1"
    port: int = 15789
    url: str = f"http://{host}:{port}"
    log_level: str = "INFO"
    db_type: str = "postgresql"
    db_host: Optional[str] = None
    db_path: Optional[str] = None
    db_name: Optional[str] = None
    db_user: Optional[str] = None
    db_pass: Optional[str] = None
    db_port: Optional[int] = None
    authorized_ips_type: list = ["public"]
    authorized_ports_state: list = ["closed"]
    random_ports: bool = True
    number_parallel_ip: int = 1
    number_check_ports: int = 10
    delay_between_check: int = 300

    class Config(ConfigVars):
        """Config."""

        pass
