import ipaddress
from typing import Any

from portswatch.classes.logs import Log
from portswatch.classes.settings import Settings
from portswatch.models.ip import IPcreateModel, IPModel

settings = Settings()
log = Log(name=__name__)


class IPController:
    def __init__(self, ip: IPModel | IPcreateModel):
        self.ip = ip.ip

    def is_ip_authorized(self):
        for ips_type in settings.authorized_ips_type:
            """
            Type of ip. According to ipaddress documentation : https://docs.python.org/3/library/ipaddress.html#ipaddress.IPv6Address
            """
            match ips_type:
                case "multicast":
                    if self.ip.is_multicast:
                        return True
                case "private":
                    if self.ip.is_private:
                        return True
                case "public":
                    if self.ip.is_global:
                        return True
                case "unspecified":
                    if self.ip.is_unspecified:
                        return True
                case "reserved":
                    if self.ip.is_reserved:
                        return True
                case "loopback":
                    if self.ip.is_loopback:
                        return True
                case "link_local":
                    if self.ip.is_link_local:
                        return True
        return False

    @staticmethod
    def is_ip(ip: Any):
        try:
            ip = ipaddress.ip_address(ip)
            return True, None
        except ValueError as err:
            return False, f"{err}"
