import sqlite3
from uuid import uuid4

from sqlalchemy import exc

from portswatch.classes.logs import Log
from portswatch.database import SessionLocal
from portswatch.models.ports import PortscreateModel, PortsModel, PortsqueryModel
from portswatch.schemas import Ports

log = Log(name=__name__)


class PortCrud:
    def add(self, port: PortscreateModel):
        port_schema = Ports(id=uuid4().bytes, ip_id=port.ip_id.bytes, port=port.port)
        with SessionLocal() as session, session.begin():
            try:
                session.add(port_schema)
            except exc.SQLAlchemyError as e:
                log.debug(
                    f"Portswatch encounter an error when it try to add {port.port}: {e}"
                )
                session.rollback()
                return False
            except sqlite3.IntegrityError as e:
                log.debug(
                    f"Sqlite encounter a problem during "
                    f"the processing of {port.port}: {e}"
                )
                return False
            else:
                session.commit()
                return True

    def get_port(self, port: PortsqueryModel | PortscreateModel):
        with SessionLocal() as session:
            port_query = (
                session.query(Ports)
                .filter(Ports.port == port.port, Ports.ip_id == port.ip_id.bytes)
                .first()
            )
            if port_query:
                return PortsModel(id=port_query.id, port=port_query.port)
            else:
                return None

    def delete(self, port: PortsModel):
        # port_schema = Ports(id=port.id, port=port.port)
        with SessionLocal() as session:
            port_query = (
                session.query(Ports)
                .filter(Ports.port == port.port, Ports.id == port.id.bytes)
                .first()
            )
        with SessionLocal() as session, session.begin():
            try:
                session.delete(port_query)
            except exc.SQLAlchemyError as e:
                log.debug(
                    f"Portswatch encounter an error when it try to add {port.port}: {e}"
                )
                session.rollback()
                return False
            except sqlite3.IntegrityError as e:
                log.debug(
                    f"Sqlite encounter a problem during "
                    f"the deletion of {port.port}: {e}"
                )
                return False
            else:
                session.commit()
                return True
