#!/usr/bin/env python3

from sqlalchemy import create_engine
from sqlalchemy.ext.declarative import declarative_base
from sqlalchemy.orm import sessionmaker
from sqlalchemy.pool import NullPool

from portswatch.classes.logs import Log
from portswatch.classes.settings import Settings

log = Log(name=__name__)
settings = Settings()

if settings.db_type == "sqlite":
    SQLALCHEMY_DATABASE_URL = f"{settings.db_type}:///{settings.db_path}"
else:
    SQLALCHEMY_DATABASE_URL = (
            f"{settings.db_type}:///"
        f"{settings.db_user}:{settings.db_pass}"
        f"@{settings.db_host}:{settings.db_port}"
        f"/{settings.db_name}"
    )

engine = create_engine(
    SQLALCHEMY_DATABASE_URL,
    echo=False,
    poolclass=NullPool,
)

SessionLocal = sessionmaker(
    autocommit=False, autoflush=False, expire_on_commit=False, bind=engine
)

Base = declarative_base()
