from sqlalchemy import Column, ForeignKey, Integer
from sqlalchemy.orm import mapped_column, relationship
from sqlalchemy.types import BINARY, VARBINARY, DateTime

from portswatch.database import Base


class IP(Base):
    __tablename__ = "ips"

    id = mapped_column(BINARY(16), primary_key=True)
    ip = Column(VARBINARY(16), unique=True)
    last_check_start = Column(DateTime, nullable=True)
    last_check_end = Column(DateTime, nullable=True)
    ports = relationship(
        "Ports",
        back_populates="ip",
        cascade="all,delete",
    )
    unexpected_ports = relationship(
        "UnexpectedPorts",
        back_populates="ip",
        cascade="all,delete",
    )
    check_ports = relationship(
        "CheckPorts",
        back_populates="ip",
        cascade="all,delete",
    )


class Ports(Base):
    __tablename__ = "ports"

    id = mapped_column(BINARY(16), primary_key=True)
    port = Column(Integer())
    ip_id = mapped_column(ForeignKey("ips.id"))
    ip = relationship("IP", back_populates="ports")


class UnexpectedPorts(Base):
    __tablename__ = "unexpected_ports"

    id = mapped_column(BINARY(16), primary_key=True)
    port = Column(Integer())
    ip_id = mapped_column(ForeignKey("ips.id"))
    ip = relationship("IP", back_populates="unexpected_ports")


class CheckPorts(Base):
    __tablename__ = "check_port"
    id = mapped_column(BINARY(16), primary_key=True)
    port = Column(Integer())
    ip_id = mapped_column(ForeignKey("ips.id"))
    ip = relationship("IP", back_populates="check_ports")
